@@ -2,9 +2,11 @@ library(testthat)
 
 test_that("model object", {
   lung2 <- lung[-14, ]
-  exp_f_fit <- mboost::blackboost(Surv(time, status) ~ age + ph.ecog,
-                                  data = lung2,
-                                  family = mboost::CoxPH())
+  exp_f_fit <- mboost::blackboost(
+    Surv(time, status) ~ age + ph.ecog,
+    data = lung2,
+    family = mboost::CoxPH()
+  )
 
   # formula method
   cox_spec <- boost_tree() %>%
@@ -51,24 +53,28 @@ test_that("survival predictions", {
   pred_time <- c(0, 100, 200, 10000)
 
   set.seed(403)
-  exp_f_fit <- mboost::blackboost(Surv(time, status) ~ age + ph.ecog,
-                                  data = lung,
-                                  family = mboost::CoxPH())
+  exp_f_fit <- mboost::blackboost(
+    Surv(time, status) ~ age + ph.ecog,
+    data = lung,
+    family = mboost::CoxPH()
+  )
   cox_spec <- boost_tree() %>%
     set_engine("mboost") %>%
     set_mode("censored regression")
   set.seed(403)
   f_fit <- fit(cox_spec, Surv(time, status) ~ age + ph.ecog, data = lung)
 
-  expect_error(predict(f_fit, lung, type = "survival"),
-               "When using 'type' values of 'survival' or 'hazard' are given")
+  expect_error(
+    predict(f_fit, lung, type = "survival"),
+    "When using `type` values of 'survival' or 'hazard', a numeric vector"
+  )
 
   set.seed(403)
-  f_pred <- predict(f_fit, lung, type = "survival", time = pred_time)
+  f_pred <- predict(f_fit, lung, type = "survival", eval_time = pred_time)
   set.seed(403)
   exp_survFit <- mboost::survFit(exp_f_fit, lung)
   exp_f_pred <- survival_curve_to_prob(
-    time = pred_time,
+    eval_time = pred_time,
     event_times = exp_survFit$time,
     survival_prob = exp_survFit$surv
   )
@@ -80,11 +86,13 @@ test_that("survival predictions", {
     all(purrr::map_lgl(f_pred$.pred, ~ all(dim(.x) == c(4, 2))))
   )
   expect_true(
-    all(purrr::map_lgl(f_pred$.pred,
-                       ~ all(names(.x) == c(".time", ".pred_survival"))))
+    all(purrr::map_lgl(
+      f_pred$.pred,
+      ~ all(names(.x) == c(".eval_time", ".pred_survival"))
+    ))
   )
   expect_equal(
-    tidyr::unnest(f_pred, cols = c(.pred))$.time,
+    tidyr::unnest(f_pred, cols = c(.pred))$.eval_time,
     rep(pred_time, nrow(lung))
   )
   expect_equal(
@@ -105,7 +113,7 @@ test_that("survival_curve_to_prob() works", {
   pred_time_general <- c(100, 200)
   exp_prob <- summary(surv_fit, time = pred_time_general)$surv
   prob <- survival_curve_to_prob(
-    time = pred_time_general,
+    eval_time = pred_time_general,
     event_times = surv_fit$time,
     survival_prob = surv_fit$surv
   )
@@ -115,17 +123,17 @@ test_that("survival_curve_to_prob() works", {
   pred_time_unordered <- c(300, 100, 200)
   exp_prob <- summary(surv_fit, time = pred_time_unordered)$surv
   prob <- survival_curve_to_prob(
-    time = pred_time_unordered,
+    eval_time = pred_time_unordered,
     event_times = surv_fit$time,
     survival_prob = surv_fit$surv
   )
-  expect_equal(prob[c(2,3,1), ], exp_prob)
+  expect_equal(prob[c(2, 3, 1), ], exp_prob)
 
   # can handle out of range time (before and after events)
   pred_time_extend <- c(-2, 0, 3000)
   exp_prob <- summary(surv_fit, time = pred_time_extend, extend = TRUE)$surv
   prob <- survival_curve_to_prob(
-    time = pred_time_extend,
+    eval_time = pred_time_extend,
     event_times = surv_fit$time,
     survival_prob = surv_fit$surv
   )
@@ -135,19 +143,19 @@ test_that("survival_curve_to_prob() works", {
   pred_time_inf <- c(-Inf, 0, Inf, 1022, -Inf)
   exp_prob <- summary(surv_fit, time = pred_time_inf)$surv
   prob <- survival_curve_to_prob(
-    time = pred_time_inf,
+    eval_time = pred_time_inf,
     event_times = surv_fit$time,
     survival_prob = surv_fit$surv
   )
   expect_equal(nrow(prob), length(pred_time_inf))
-  expect_equal(prob[c(2, 4),], exp_prob)
+  expect_equal(prob[c(2, 4), ], exp_prob)
   expect_equal(
-    prob[c(1, 5),],
+    prob[c(1, 5), ],
     matrix(1, nrow = 2, ncol = nrow(lung_pred)),
     ignore_attr = "dimnames"
   )
   expect_equal(
-    prob[3,] %>% unname(),
+    prob[3, ] %>% unname(),
     rep(0, nrow(lung_pred))
   )
 })
@@ -163,8 +171,8 @@ test_that("survival_prob_mboost() works", {
   # can handle missings
   pred <- survival_prob_mboost(
     mboost_object,
-    new_data = lung[14:15,],
-    time = c(0, 100, 200)
+    new_data = lung[14:15, ],
+    eval_time = c(0, 100, 200)
   )
   expect_equal(nrow(pred), 2)
 
@@ -174,7 +182,7 @@ test_that("survival_prob_mboost() works", {
   # pred <- survival_prob_mboost(
   #   mboost_object,
   #   new_data = lung[1,],
-  #   time = c(0, 100, 200)
+  #   eval_time = c(0, 100, 200)
   # )
   # expect_equal(nrow(pred), 1)
 })
@@ -183,9 +191,11 @@ test_that("survival_prob_mboost() works", {
 
 test_that("linear_pred predictions", {
   lung2 <- lung[-14, ]
-  exp_f_fit <- mboost::blackboost(Surv(time, status) ~ age + ph.ecog,
-                                  data = lung2,
-                                  family = mboost::CoxPH())
+  exp_f_fit <- mboost::blackboost(
+    Surv(time, status) ~ age + ph.ecog,
+    data = lung2,
+    family = mboost::CoxPH()
+  )
   cox_spec <- boost_tree() %>%
     set_engine("mboost") %>%
     set_mode("censored regression")
@@ -207,6 +217,51 @@ test_that("linear_pred predictions", {
   expect_true(all(names(f_pred) == ".pred_linear_pred"))
   expect_equal(f_pred$.pred_linear_pred, as.vector(exp_f_pred))
   expect_equal(nrow(f_pred), nrow(lung2))
+
+  # single observation
+  f_pred_1 <- predict(f_fit, lung2[1, ], type = "linear_pred")
+  expect_identical(nrow(f_pred_1), 1L)
 })
 
 
+# fit via matrix interface ------------------------------------------------
+
+test_that("`fix_xy()` works", {
+  lung_x <- as.matrix(lung[, c("age", "ph.ecog")])
+  lung_y <- Surv(lung$time, lung$status)
+  lung_pred <- lung[1:5, ]
+
+  spec <- boost_tree() %>%
+    set_engine("mboost") %>%
+    set_mode("censored regression")
+  f_fit <- fit(spec, Surv(time, status) ~ age + ph.ecog, data = lung)
+  xy_fit <- fit_xy(spec, x = lung_x, y = lung_y)
+
+  expect_equal(
+    f_fit$fit,
+    xy_fit$fit,
+    ignore_function_env = TRUE
+  )
+
+  f_pred_time <- predict(f_fit, new_data = lung_pred, type = "time")
+  xy_pred_time <- predict(xy_fit, new_data = lung_pred, type = "time")
+  expect_equal(f_pred_time, xy_pred_time)
+
+  f_pred_survival <- predict(
+    f_fit,
+    new_data = lung_pred,
+    type = "survival",
+    eval_time = c(100, 200)
+  )
+  xy_pred_survival <- predict(
+    xy_fit,
+    new_data = lung_pred,
+    type = "survival",
+    eval_time = c(100, 200)
+  )
+  expect_equal(f_pred_survival, xy_pred_survival)
+
+  f_pred_lp <- predict(f_fit, new_data = lung_pred, type = "linear_pred")
+  xy_pred_lp <- predict(xy_fit, new_data = lung_pred, type = "linear_pred")
+  expect_equal(f_pred_lp, xy_pred_lp)
+})
