@@ -47,6 +47,10 @@ test_that("time predictions", {
   expect_true(all(names(f_pred) == ".pred_time"))
   expect_equal(f_pred$.pred_time, unname(exp_f_pred))
   expect_equal(nrow(f_pred), nrow(lung))
+
+  # single observation
+  f_pred_1 <- predict(f_fit, lung[1, ], type = "time")
+  expect_identical(nrow(f_pred_1), 1L)
 })
 
 
@@ -63,9 +67,11 @@ test_that("survival predictions", {
   set.seed(1234)
   f_fit <- fit(cox_spec, Surv(time, status) ~ age + ph.ecog, data = lung)
 
-  expect_error(predict(f_fit, lung, type = "survival"),
-               "When using 'type' values of 'survival' or 'hazard' are given")
-  f_pred <- predict(f_fit, lung, type = "survival", time = 100:200)
+  expect_error(
+    predict(f_fit, lung, type = "survival"),
+    "When using `type` values of 'survival' or 'hazard', a numeric vector"
+  )
+  f_pred <- predict(f_fit, lung, type = "survival", eval_time = 100:200)
 
   expect_s3_class(f_pred, "tbl_df")
   expect_equal(names(f_pred), ".pred")
@@ -75,18 +81,21 @@ test_that("survival predictions", {
     101
   )
   cf_names <-
-    c(".time", ".pred_survival")
+    c(".eval_time", ".pred_survival")
   expect_true(
-    all(purrr::map_lgl(f_pred$.pred,
-                       ~ identical(names(.x), cf_names)))
+    all(purrr::map_lgl(
+      f_pred$.pred,
+      ~ identical(names(.x), cf_names)
+    ))
   )
   expect_equal(
-    tidyr::unnest(f_pred, cols = c(.pred))$.time,
+    tidyr::unnest(f_pred, cols = c(.pred))$.eval_time,
     rep(100:200, nrow(lung))
   )
 
-  f_pred <- predict(f_fit, lung[1,], type = "survival", time = 306)
-  new_km <- predict(exp_f_fit, newdata = lung[1,], type = "prob")[[1]]
+  # single observation
+  f_pred <- predict(f_fit, lung[1, ], type = "survival", eval_time = 306)
+  new_km <- predict(exp_f_fit, newdata = lung[1, ], type = "prob")[[1]]
   # Prediction should be fairly near the actual value
 
   expect_equal(
@@ -94,5 +103,52 @@ test_that("survival predictions", {
     new_km$surv[new_km$time == 306],
     tolerance = .1
   )
+})
 
+
+# fit via matrix interface ------------------------------------------------
+
+test_that("`fix_xy()` works", {
+  lung_x <- as.matrix(lung[, c("age", "ph.ecog")])
+  lung_y <- Surv(lung$time, lung$status)
+  lung_pred <- lung[1:5, ]
+
+  spec <- decision_tree() %>%
+    set_mode("censored regression") %>%
+    set_engine("partykit")
+  set.seed(1)
+  f_fit <- fit(spec, Surv(time, status) ~ age + ph.ecog, data = lung)
+  set.seed(1)
+  xy_fit <- fit_xy(spec, x = lung_x, y = lung_y)
+
+  # prep for model comparison
+  f_fit_fit <- unclass(f_fit$fit)
+  xy_fit_fit <- unclass(xy_fit$fit)
+  elements_to_ignore <- c("call", "data", "terms")
+  f_ignore <- which(names(f_fit_fit) %in% elements_to_ignore)
+  xy_ignore <- which(names(xy_fit_fit) %in% elements_to_ignore)
+
+  expect_equal(
+    f_fit_fit[-f_ignore],
+    xy_fit_fit[-xy_ignore],
+    ignore_function_env = TRUE
+  )
+
+  f_pred_time <- predict(f_fit, new_data = lung_pred, type = "time")
+  xy_pred_time <- predict(xy_fit, new_data = lung_pred, type = "time")
+  expect_equal(f_pred_time, xy_pred_time)
+
+  f_pred_survival <- predict(
+    f_fit,
+    new_data = lung_pred,
+    type = "survival",
+    eval_time = c(100, 200)
+  )
+  xy_pred_survival <- predict(
+    xy_fit,
+    new_data = lung_pred,
+    type = "survival",
+    eval_time = c(100, 200)
+  )
+  expect_equal(f_pred_survival, xy_pred_survival)
 })
